image_exists_in_host_storage

Function image_exists_in_host_storage 

async fn image_exists_in_host_storage(image: &str) -> Result<bool>
Check if an image exists in the default containers-storage (podman storage).

TODO: Using exit codes to check image existence is not ideal. We should use the podman native libpod HTTP API to properly communicate with podman and get structured responses.